==> tuia-explore-center-api-0.0.1-20190530.113355-37-sources.jar: cn/tuia/explore/center/api/dto/rsp/PostDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import cn.tuia.explore.center.api.dto.req.PostPublishDto;

import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: PostDto.java , v 0.1 2019-05-23 17:41 ElinZhou Exp $
 */
public class PostDto extends PostPublishDto {
    private static final long serialVersionUID = 7398636528456083335L;
    /**
     * 帖子id
     */
    private long id;

    /**
     * 分享次数
     */
    private long shareTimes;

    /**
     * 评论次数
     */
    private long commentTimes;

    /**
     * 点赞次数
     */
    private long likeTimes;

    /**
     * 时间描述
     */
    private String publishTimeDesc;

    /**
     * 时间描述
     */
    private Date publishTime;

    public long getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(long shareTimes) {
        this.shareTimes = shareTimes;
    }

    public long getCommentTimes() {
        return commentTimes;
    }

    public void setCommentTimes(long commentTimes) {
        this.commentTimes = commentTimes;
    }

    public long getLikeTimes() {
        return likeTimes;
    }

    public void setLikeTimes(long likeTimes) {
        this.likeTimes = likeTimes;
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }


    public String getPublishTimeDesc() {
        return publishTimeDesc;
    }

    public void setPublishTimeDesc(String publishTimeDesc) {
        this.publishTimeDesc = publishTimeDesc;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }
}

==> tuia-explore-center-api-0.0.1-20190602.055516-53-sources.jar: cn/tuia/explore/center/api/dto/rsp/PostDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import cn.tuia.explore.center.api.dto.req.PostPublishDto;

import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: PostDto.java , v 0.1 2019-05-23 17:41 ElinZhou Exp $
 */
public class PostDto extends PostPublishDto {
    private static final long serialVersionUID = 7398636528456083335L;
    /**
     * 帖子id
     */
    private Long id;

    /**
     * 分享次数
     */
    private long shareTimes;

    /**
     * 评论次数
     */
    private long commentTimes;

    /**
     * 点赞次数
     */
    private long likeTimes;

    /**
     * 时间描述
     */
    private String publishTimeDesc;

    /**
     * 时间描述
     */
    private Date publishTime;

    /**
     * 图片数量
     */
    private Integer imageCount;

    /**
     * 当前用户是否关注了该作者
     */
    private boolean follow;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public long getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(long shareTimes) {
        this.shareTimes = shareTimes;
    }

    public long getCommentTimes() {
        return commentTimes;
    }

    public void setCommentTimes(long commentTimes) {
        this.commentTimes = commentTimes;
    }

    public long getLikeTimes() {
        return likeTimes;
    }

    public void setLikeTimes(long likeTimes) {
        this.likeTimes = likeTimes;
    }

    public String getPublishTimeDesc() {
        return publishTimeDesc;
    }

    public void setPublishTimeDesc(String publishTimeDesc) {
        this.publishTimeDesc = publishTimeDesc;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public Integer getImageCount() {
        return imageCount;
    }

    public void setImageCount(Integer imageCount) {
        this.imageCount = imageCount;
    }

    public boolean isFollow() {
        return follow;
    }

    public void setFollow(boolean follow) {
        this.follow = follow;
    }
}
